
<?php
class Settings {

	private static $lDebug = 0;

	public function getDebug() {
		return (isset($_GET["debug"]) && $_GET["debug"] == 1);
	}

	/**
	* Set the name of the dreambox
	* @access private
	* @var string
	*/
	private static $dreamboxName = "Yoshie's Dreambox";

	/**
	* Set the local IP address of your dreambox. Should be an internal IP number or hostname. For best performance, use an IP number.
	* @access private
	* @var string
	*/
	private static $dreamboxIP = "192.168.5.119";

	/**
	* Set the username for the dreambox webinterface. Leave empty when no authentication is required.
	* @access private
	* @var string
	*/
	private static $dreamboxUserName = "";

	/**
	* Set the password for the dreambox webinterface. Leave empty when no authentication is required.
	* @access private
	* @var string
	*/
	private static $dreamboxPassword = "";

	/**
	* Set the enigma version of the dreambox. Valid values are enigma1 of enigma2
	* @access private
	* @var string
	*/
	private static $dreamboxEnigmaVersion = "enigma2";

	/**
	* Set the the internal port number for streaming.
	* @access private
	* @var string
	*/
	private static $vlcLanStreamPort = "8668";

	/**
	* Set the external IP or hostname for external connections to the VLC Server
	* @access private
	* @var string
	*/
	private static $vlcIP = "192.168.5.1";

	/**
	* Set the external IP or hostname for external connections to the Wowza Media Server
	* @access private
	* @var string
	*/
	private static $wowzaServerName = "wowza.theyosh.nl";

	/**
	* Set the the program name. Should not be changed
	* @access private
	* @var string
	*/
	private static $lProgramName = "Dreambox ReStream";

	/**
	* Set the program version. Should not be changed
	* @access private
	* @var string
	*/
	private static $lVersion = "2.0 &#593;3";


	//private static $lMoviesPath = "/media/film/";
	private static $lMoviesPath = "";


	private static $lValidMovies = "avi,mkv,mpeg,mpg,mp4";

	private static $lMediaInfoLocationLinux = "/usr/bin/mediainfo";
	private static $lMediaInfoLocationMacOSX = "";
	private static $lMediaInfoLocationWindows = "";

	static public function getMediaInfoxecutable() {
		if (Utils::isWindows()) {
			return trim(Settings::$lMediaInfoLocationWindows);
		} elseif (Utils::isMacOSX()) {
			return trim(Settings::$lMediaInfoLocationMacOSX);
		} elseif (Utils::isLinux()) {
			return trim(Settings::$lMediaInfoLocationLinux);
		}
	}

	/**
	* Set the location of the VLC server executable on a Linux system
	* You can leave it empty if you use a Windows server
	* @access private
	* @var string
	*/
	private static $lVLCLocationLinux = "/usr/bin/vlc";

	/**
	* Set the location of the VLC server executable on a Windows system
	* You can leave it empty if you use a Linux server
	* Pay atention on the / instead of windows normal \
	* @access private
	* @var string
	*/
	private static $lVLCLocationWindows = "C:/Progra~1/VideoLAN/VLC/vlc.exe";

	/**
	* Set the location of the VLC server executable on a MacOSX system
	* You can leave it empty if you use a Windows server
	* @access private
	* @var string
	*/
	private static $lVLCLocationMacOSX = "/Applications/VLC.app/Contents/MacOS/VLC";

	/**
	* Return the VLC executable based on OS type.
	* @return string
	*/
	static public function getVLCExecutable() {
		if (Utils::isWindows()) {
			return trim(Settings::$lVLCLocationWindows);
		} elseif (Utils::isMacOSX()) {
			return trim(Settings::$lVLCLocationMacOSX);
		} elseif (Utils::isLinux()) {
			return trim(Settings::$lVLCLocationLinux);
		}
	}

	/**
	* Set true to enable Flash H.264 streaming through a wowza server
	* @access private
	* @var boolean
	*/
	private static $lWowza = true;

	/**
	* Check if Wowza is supported. Returns true when Wowza is enabled, and therefore show a rtmp transport option that uses Wowza
	* @return boolean
	*/
	static public function isWowzaEnabled() {
		return (Settings::$lWowza === true);
	}

	/**
	* Set this value to enable the ggrab program. This is only available on windows.
	* Leave it blank to disable it.
	* @access private
	* @var string
	*/
	private static $lGrabLocationWindows = "";
	//private static $lGgrabLocationWindows = "C:/ggrab/ggrab.exe";

	/**
	* Returns the location of ggrab program. When empty, ggrab is disabled.
	* @return string
	*/
	static public function getGgrabLocation() {
		return trim(Settings::$lGrabLocationWindows);
	}

	/**
	* Get the next program from the program guide.
	* @return string
	*/
	static public function getDreamboxName() {
		return trim(Settings::$dreamboxName);
	}

	/**
	* Get the IP number of the dreambox.
	* @return string
	*/
	static public function getDreamboxIP() {
		return gethostbyname(trim(Settings::$dreamboxIP));
	}

	/**
	* Get the username of the dreambox.
	* @return string
	*/
	static public function getDreamboxUserName() {
		return trim(Settings::$dreamboxUserName);
	}

	/**
	* Get the password of the dreambox.
	* @return string
	*/
	static public function getDreamboxPassword() {
		return trim(Settings::$dreamboxPassword);
	}

	/**
	* Get the enigma version of the dreambox.
	* @return string
	*/
	static public function getEnigmaVersion() {
		return trim(Settings::$dreamboxEnigmaVersion);
	}

	/**
	* Get the VLC Server internal IP number.
	* @return string
	*/
	static public function getVLCIP() {
		return trim(gethostbyname(Settings::$vlcIP));
	}

	/**
	* Get the internal streaming port of the VLC Server.
	* @return string
	*/
	static public function getVLCPort() {
		return trim(Settings::$vlcLanStreamPort);
	}

	static public function getWowzaServerName() {
		return trim(Settings::$wowzaServerName);
	}

	/**
	* Get the program name.
	* @return string
	*/
	static public function getProgramName() {
		return trim(Settings::$lProgramName);
	}

	/**
	* Get the program version number.
	* @return string
	*/
	static public function getVersionNumber() {
		return trim(Settings::$lVersion);
	}

	/**
	* If you want to make Dreambox Restream private, set the variable below to 1 and set the username and password
	*
	*/
	private static $lPivateModus = 0;

	static public function isPrivate() {
		return Settings::$lPivateModus == 1;
	}

	private static $lPrivateModusUsername = "dreambox";

	static public function getPrivateModusUsername() {
		return trim(Settings::$lPrivateModusUsername);
	}

	private static $lPrivateModusPassword = "dreambox";

	static public function getPrivateModusPassword() {
		return trim(Settings::$lPrivateModusPassword);
	}

	static public function getMoviesPath() {
		return trim(Settings::$lMoviesPath);
	}

	static public function getValidMovies() {
		return explode(",",Settings::$lValidMovies);
	}
}
?>