<?php
class VLCServer {

	/**
	* @access private
	* @var array
	*/
	private $lDimensions;

	/**
	* @access private
	* @var string
	*/
	private $lChannel;

	/**
	* @access private
	* @var string
	*/
	private $lAudioCodec;

	/**
	* @access private
	* @var string
	*/
	private $lVideoCodec;

	/**
	* @access private
	* @var int
	*/
	private $lFPS;

	/**
	* @access private
	* @var string
	*/
	private $lStreamType;

	/**
	* @access private
	* @var int
	*/
	private $lBitrate;

   	/**
	* @access private
	* @var int
	*/
	private $lAudioBitrate;

	/**
	* @access private
	* @var int
	*/
	private $lVolume;

	/**
	* @access private
	* @var int
	*/
	private $lScale;

	/**
	* @access private
	* @var string
	*/
	private $lVLCExecutable;

	/**
	* @access private
	* @var int
	*/
	private $lChannels;

	/**
	* Constructor. This creates a VLC Server object. Some defaults are already set. These are: volume, scale and audio channels. It alse detects if it is running on Windows or Linux.
	* @return VLCServer
	*/
	function __construct() {
		$this->lDimensions = array(720,404);
		$this->lVLCExecutable = Settings::getVLCExecutable();
		$this->lVolume = 80;
		$this->lScale = 0.6;
		$this->lChannels = 2;
		$this->lAudioCodec = "mp3";
		$this->lVideoCodec = "x264";
		$this->lFPS = 25;
		$this->lBitrate = 500;
		$this->lAudioBitrate = 64;
		$this->lStreamType = "rtmp";
	}

	/**
	* Set the VLC Server encoding dimentions. This is the size of the re-encoded stream.
	* @param string $pSizes
	*/
	public function setDimentions($pSizes) {
		$pSizes = explode("x",$pSizes);
		if (is_array($pSizes) && sizeof($pSizes) == 2 && is_numeric($pSizes[0]) && is_numeric($pSizes[1])) {
			$this->lDimensions = $pSizes;
		}
	}

	/**
	* Set the VLC Server encoding audio codec. This sets the output audio codec.
	* @param string $pCodec
	*/
	public function setAudioCodec($pCodec) {
		if ( ($pCodec = trim($pCodec)) != "") $this->lAudioCodec = $pCodec;
	}

	/**
	* Set the VLC Server encoding video codec. This sets the output video codec.
	* @param string $pCodec
	*/
	public function setVideoCodec($pCodec) {
		if ( ($pCodec = trim($pCodec)) != "") $this->lVideoCodec = $pCodec;
	}

	/**
	* Set the VLC Server frames per second.
	* @param string $pFPS
	*/
	public function setFPS($pFPS) {
		if ( is_numeric($pFPS = trim($pFPS)) ) $this->lFPS = $pFPS;
	}

	/**
	* Set the VLC Server streaming video bitrate. The higher the bitrate, the better the image qualitiy will be.
	* @param string $pRate
	*/
	public function setBitrate($pRate) {
		if ( is_numeric($pRate = trim($pRate)) ) $this->lBitrate = $pRate;
	}

   	/**
	* Set the VLC Server streaming audio bitrate. The higher the bitrate, the better the audio qualitiy will be.
	* @param string $pRate
	*/
	public function setAudioBitrate($pRate) {
		if ( is_numeric($pRate = trim($pRate)) ) $this->lAudioBitrate = $pRate;
	}

	/**
	* Start the VLC Server by executing the vlc command line. You have to set all options before starting this server. If the server is started, you should be able to connect to it and watch some tv.
	* @param boolean $pDebug
	* @return string
	*/
	public function startServer($pStreamURL,$pChannelName = "",$pMobile = false) {
		global $gDebugObj;
		$lCurrentStatus = $this->getCurrentStatus();
		if ($lCurrentStatus["streamurl"] == $pStreamURL) return; // Don't zap if it is the same channel...
		$this->stopServer();
		sleep(2);
		$lCMD = $this->lVLCExecutable . " -I dummy \"" . $pStreamURL . "\" vlc://quit";

		if (Settings::getGgrabLocation() != "") {
			$lCMD = Settings::getGgrabLocation() . " -host " . Settings::getDreamboxIP() . " -q -o - -p 0x1006 0x1106 | " . $this->lVLCExecutable . " - ";
		}

		$lCMD .= " --sout=";
		//$lTransCode = "#transcode{aud,venc=". $this->lVideoCodec . "{keyint=" . ($this->lFPS*2) . ",cabac,level=30,fps=" . $this->lFPS . "}" . ",vcodec=". $this->lVideoCodec . ",vb=". $this->lBitrate . ",scale=". $this->lScale .",acodec=". $this->lAudioCodec .",ab=" . $this->lAudioBitrate . ",channels=". $this->lChannels .",samplerate=44100,deinterlace,width=". $this->lDimensions[0] .",height=". $this->lDimensions[1] . ",maxwidth=" . $this->lDimensions[0] . ",maxheight=" . $this->lDimensions[1] .",canvas-width=720,canvas-height=405,aspect=16:9,canvas-aspect=16:9,audio-sync,fps=" . $this->lFPS . "}";
		//$lTransCode = "#transcode{venc=". $this->lVideoCodec . "{keyint=" . ($this->lFPS*2) . ",cabac,level=30,fps=" . $this->lFPS . "}" . ",vcodec=". $this->lVideoCodec . ",vb=". $this->lBitrate . ",scale=". $this->lScale .",acodec=". $this->lAudioCodec .",ab=" . $this->lAudioBitrate . ",channels=". $this->lChannels .",samplerate=48000,deinterlace,width=". $this->lDimensions[0] .",height=". $this->lDimensions[1] . ",maxwidth=" . $this->lDimensions[0] . ",maxheight=" . $this->lDimensions[1] .",canvas-width=720,canvas-height=405,aspect=16:9,canvas-aspect=16:9,audio-sync,fps=" . $this->lFPS . "}";
		//qpmax=36,qpmin=10,me=hex,merange=24,subme=9,qcomp=0.6,
		$lTransCode = "#transcode{venc=". $this->lVideoCodec . "{keyint=" . ($this->lFPS*2) . ",profile=baseline,level=3.0,nocabac,fps=" . $this->lFPS . "}" . ",vcodec=". $this->lVideoCodec . ",vb=". $this->lBitrate . ",scale=". $this->lScale .",acodec=". $this->lAudioCodec .",ab=" . $this->lAudioBitrate . ",channels=". $this->lChannels .",samplerate=48000,deinterlace,width=". $this->lDimensions[0] .",height=". $this->lDimensions[1] . ",audio-sync,fps=" . $this->lFPS . "}";
		
		if (Settings::isWowzaEnabled()) {
			$lTransCode .= ":rtp{dst=". Settings::getVLCIP() .",port-video=10000,port-audio=10002,sdp=http://". Settings::getVLCIP() .":". Settings::getVLCPort() ."/restream.sdp}";
		} else {
			$lTransCode .= ":gather:std{access=http,mime='video/mp4',dst=" . Settings::getVLCIP() .":". Settings::getVLCPort() . "/restream.mp4,mux=ffmpeg{mux=flv}}";
		}
		if (Utils::isLinux() || Utils::isMacOSX()) {
			$lTransCode = "\"" . $lTransCode . "\"";
		}
		$lCMD .= $lTransCode;

		if (Utils::isLinux() || Utils::isMacOSX()) {
			//$lCMD .= " >>/dev/null 2>>/dev/null &";
			$lCMD .= " >" .getcwd() . "/tmp/restream_2.0_vlc.error.log 1>" .getcwd() . "/tmp/restream_2.0_vlc.1.log 2>" .getcwd() . "/tmp/restream_2.0_vlc.log &";
			shell_exec($lCMD);
		} elseif(Utils::isWindows()) {
			$WshShell = new COM("WScript.Shell");
			$oExec = $WshShell->Run("$lCMD", 3, false);
		}
		//if (Utils::isLinux()) $this->startChunker($pChannelName);
		if (Settings::getDebug()) {
			$gDebugObj->setDebugMessage("VLC Command:\n".$lCMD);
		}
	}

	public function getCurrentStatus() {
		$lReturnArray = array();
		$lReturnArray["channel"] = "";
		$lReturnArray["streamurl"] = "";
		if (Utils::isLinux() || Utils::isMacOSX()) {
			$lData = trim(shell_exec("ps ax | grep -i vlc | grep -v grep"));
			$lStartPos = stripos($lData,$this->lVLCExecutable);
			$lData = trim(substr($lData,strlen($this->lVLCExecutable . " -I dummy")+$lStartPos));
//echo "VLC STatus data:\n" . $lData . "\n";
			$lReturnArray["streamurl"] = trim(substr($lData,0,stripos($lData,"vlc://quit")));
			if (substr($lReturnArray["streamurl"],0,7) == "http://") {
				$lReturnArray["channel"] = explode("/",$lReturnArray["streamurl"]);
				$lReturnArray["channel"] = end($lReturnArray["channel"]);
			} else {
				$lReturnArray["channel"] = $lReturnArray["streamurl"];
			}
		}
		return $lReturnArray;
	}

	private function startChunker($pChannelName) {
		$lChunkerFolder = "apps/chunker/";
		$pChannelName = str_replace(" ","_",$pChannelName);
		$lCurrentDir = getcwd();
		chdir($lChunkerFolder);
		shell_exec("rm ../../iphone/stream/*");
		shell_exec("rm ../../tmp/*.ts");
		$lChunkerConfigFileContents = file_get_contents("dreambox.temp.yml");
		$lChunkerConfigFileContents = str_replace("[CHANNEL]",$pChannelName,$lChunkerConfigFileContents);
		if (Settings::isWowzaEnabled()) {
			$lChunkerConfigFileContents = str_replace("[FULL_RTSP_URL]","rtsp://" . Settings::getWowzaServerName() . "/dreambox/" . $pChannelName,$lChunkerConfigFileContents);
		} else {
			$lChunkerConfigFileContents = str_replace("[FULL_RTSP_URL]","http://" . Settings::getVLCIP() . ":" . Settings::getVLCPort() . "/restream.mp4?" . $pChannelName,$lChunkerConfigFileContents);
		}
		file_put_contents("./dreambox.yml",$lChunkerConfigFileContents);
		shell_exec("/usr/bin/killall -Iq ruby");
		shell_exec("/usr/bin/killall -Iq ffmpeg");
		sleep(3);
		shell_exec("./http_streamer.rb dreambox.yml >/dev/null &");
		chdir($lCurrentDir);
	}

	/**
	* Stop the VLC Server. This is handy to spare some system resources.
	*/
	public function stopServer() {
		if (Utils::isLinux()) {
			$lCMD = "killall -Iq vlc ruby ffmpeg";
			shell_exec($lCMD);
		} elseif(Utils::isMacOSX()) {
			$lCMD = "killall VLC";
			shell_exec($lCMD);
		} elseif(Utils::isWindows()) {
			// But you need to download this one: http://www.beyondlogic.org/solutions/processutil/processutil.htm
			// And install it in a dir called apps in the restream root dir
			exec(getcwd() . "\apps\Process.exe -k vlc.exe");
		}
	}

	private function getProgramIDs() {
		if (Utils::isLinux()) {

		}
	}


	/**
	* Check if the server is still running.
	* @return boolean
	*/
	public function isServerRunning() {
		//return false;
		if (Utils::isLinux() || Utils::isMacOSX()) {
			$lData = trim(shell_exec("ps ax | grep -i vlc | grep -v grep | grep " . Settings::getDreamboxIP()));
		} elseif(Utils::isWindows()) {
			// On windows it is not possible to distinquish different vlc processes... so if there is a VLC proces, the server is running...
			$lCMD = getcwd() . "\apps\Process.exe | " . getcwd()  . "\apps\grep.exe vlc";
			$lData = trim(shell_exec($lCMD));
		}
		return (strlen($lData) > 0);
	}
}
?>
